@@ -43,7 +43,7 @@ def train(datadict,*args, **kwargs):
     return model
 
 def update(datadict,model):
-    return train(datadict,model)
+    return train(datadict,model=model)
 
 def classify(datadict,model):
     classifications = {}
